@@ -1,16 +1,17 @@
+# $File: //depot/OurNet-BBS/BBS/MAPLE3/Group.pm $ $Author: autrijus $
+# $Revision: #4 $ $Change: 1204 $ $DateTime: 2001/06/18 19:29:55 $
+
 package OurNet::BBS::MAPLE3::Group;
-$VERSION = "0.1";
 
 use strict;
 use base qw/OurNet::BBS::Base/;
 use fields qw/bbsroot group mtime _cache/;
-use OurNet::BBS::MAPLE3::Board;
 
-use constant GEM_FOLDER         => 0x00010000;
-use constant GEM_BOARD          => 0x00020000;
-use constant GEM_GOPHER         => 0x00040000;
-use constant GEM_HTTP           => 0x00080000;
-use constant GEM_EXTEND         => 0x80000000;
+use constant GEM_FOLDER		=> 0x00010000;
+use constant GEM_BOARD		=> 0x00020000;
+use constant GEM_GOPHER		=> 0x00040000;
+use constant GEM_HTTP		=> 0x00080000;
+use constant GEM_EXTEND		=> 0x80000000;
 
 BEGIN {
     __PACKAGE__->initvars(
@@ -26,11 +27,10 @@ sub refresh_meta {
     my $file = "$self->{bbsroot}/gem/@/@".$self->{group};
     my $board;
     return unless $self->{group};
-    local *GROUP;
-
     return if $self->{mtime} and (stat($file))[9] == $self->{mtime};
 
-    open (GROUP, $file) or open (GROUP, "+>>$file")
+    my $GROUP;
+    open($GROUP, $file) or open ($GROUP, '+>>', $file)
         or die("Cannot read group file $file: $!");
 
     $self->{mtime} = (stat($file))[9];
@@ -39,18 +39,20 @@ sub refresh_meta {
     local $/ = \$packsize;
     my %foo;
     my $buf;
-    while ($buf = <GROUP> and @foo{@packlist} = unpack($packstring, $buf)) {
+    while ($buf = <$GROUP> and @foo{@packlist} = unpack($packstring, $buf)) {
 	$foo{id} =~ s/^@//;
 	if ($foo{xmode} & GEM_BOARD) {
-            $self->{_cache}{$foo{id}} = OurNet::BBS::MAPLE3::Board->new(
+            $self->{_cache}{$foo{id}} = $self->module('Board')->new(
                 $self->{bbsroot}, $foo{id}
             );
 
 	}
 	elsif ($foo{xmode} & GEM_FOLDER) {
-            $self->{_cache}{$foo{id}} = OurNet::BBS::MAPLE3::Group->new(
+            $self->{_cache}{$foo{id}} = $self->module('Group')->new(
                 $self->{bbsroot}, $foo{id});
 	}
     }
-    close GROUP;
+    close $GROUP;
 }
+
+1;
